@@ -167,64 +167,64 @@ class ClBuilderUpdateAction(Action):
                  'method': 'Builder.modify_binary_depends('
                            'builder.cl_builder_with_bdeps_opt_set,builder.cl_builder_path)'
                 },
-                {'name': 'emerge_update_world',
-                 'group': __("Updating packages"),
-                 'tasks': [
-                     {'name': 'update_world',
-                      'message': __("Calculating dependencies"),
-                      'method': 'Builder.emerge_ask('
-                                'update.cl_update_pretend_set,'
-                                '"-uDN","--rebuilt-binaries",'
-                                '"@world")',
-                      'condition': lambda Get:
-                          Get('cl_builder_rebuilt_binaries_set') == 'on'
-                      },
-                     {'name': 'update_world',
-                      'message': __("Calculating dependencies"),
-                      'method': 'Builder.emerge_ask('
-                                'update.cl_update_pretend_set,'
-                                '"-uDN","@world")',
-                      'condition': lambda Get:
-                          Get('cl_builder_rebuilt_binaries_set') != 'on'
-                      }
-                 ],
-                 'condition': lambda Get: (
-                     Get('update.cl_update_sync_only_set') == 'off')
-                 },
+                # {'name': 'emerge_update_world',
+                #  'group': __("Updating packages"),
+                #  'tasks': [
+                #      {'name': 'update_world',
+                #       'message': __("Calculating dependencies"),
+                #       'method': 'Builder.emerge_ask('
+                #                 'update.cl_update_pretend_set,'
+                #                 '"-uDN","--rebuilt-binaries",'
+                #                 '"@world")',
+                #       'condition': lambda Get:
+                #           Get('cl_builder_rebuilt_binaries_set') == 'on'
+                #       },
+                #      {'name': 'update_world',
+                #       'message': __("Calculating dependencies"),
+                #       'method': 'Builder.emerge_ask('
+                #                 'update.cl_update_pretend_set,'
+                #                 '"-uDN","@world")',
+                #       'condition': lambda Get:
+                #           Get('cl_builder_rebuilt_binaries_set') != 'on'
+                #       }
+                #  ],
+                #  'condition': lambda Get: (
+                #      Get('update.cl_update_sync_only_set') == 'off')
+                #  },
                 {'name': 'update_other',
                  'condition': lambda Get: (
                      Get('update.cl_update_pretend_set') == 'off' and
                      Get('update.cl_update_sync_only_set') == 'off')
                  },
-                # {'name': 'update_other:group_changed_packages',
-                #  'group': __("Rebuild modified packages"),
-                #  'tasks': [
-                #      {'name': 'changed_packages',
-                #       'message': __("Calculating dependencies"),
-                #       'method': 'Builder.rebuild_changed_packages('
-                #                 'cl_builder_path,'
-                #                 'cl_builder_repository_data)',
-                #       'condition': lambda Get:
-                #       Get('cl_builder_rebuild_changed_set') == 'on'
-                #       }
-                #  ]
-                #  },
-                # {'name': 'update_other:update_perl',
-                #  'group': __("Updating Perl modules"),
-                #  'tasks': [
-                #      {'name': 'perl_cleaner',
-                #       'message': __(
-                #           'Find & rebuild packages and Perl header files '
-                #           'broken due to a perl upgrade'),
-                #       'method': 'Builder.chroot_emergelike(cl_builder_path,'
-                #                 '"perl-cleaner","all")',
-                #       'condition': BuilderConditions.was_installed(
-                #           'dev-lang/perl$', EmergeMark.PerlCleaner),
-                #       'decoration': 'Builder.update_task("%s")'
-                #                     % EmergeMark.PerlCleaner
-                #       },
-                #  ]
-                #  },
+                {'name': 'update_other:group_changed_packages',
+                 'group': __("Rebuild modified packages"),
+                 'tasks': [
+                     {'name': 'changed_packages',
+                      'message': __("Calculating dependencies"),
+                      'method': 'Builder.rebuild_changed_packages('
+                                'cl_builder_path,'
+                                'cl_builder_repository_data)',
+                      'condition': lambda Get:
+                      Get('cl_builder_rebuild_changed_set') == 'on'
+                      }
+                 ]
+                 },
+                {'name': 'update_other:update_perl',
+                 'group': __("Updating Perl modules"),
+                 'tasks': [
+                     {'name': 'perl_cleaner',
+                      'message': __(
+                          'Find & rebuild packages and Perl header files '
+                          'broken due to a perl upgrade'),
+                      'method': 'Builder.chroot_emergelike(cl_builder_path,'
+                                '"perl-cleaner","all")',
+                      'condition': BuilderConditions.was_installed(
+                          'dev-lang/perl$', EmergeMark.PerlCleaner),
+                      'decoration': 'Builder.update_task("%s")'
+                                    % EmergeMark.PerlCleaner
+                      },
+                 ]
+                 },
                 {'name': 'update_other:depclean',
                  'group': __("Cleaning the system from needless packages"),
                  'tasks': [
